#
# spec file for package libmbim
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libmbim
Version:        1.14.0
Release:        3.4
Summary:        Mobile Interface Broadband Model (MBIM) protocol
License:        GPL-2.0+ and LGPL-2.0+
Group:          Productivity/Networking/System
Url:            http://www.freedesktop.org/wiki/Software/libmbim/
Source:         http://www.freedesktop.org/software/libmbim/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 147
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libmbim is a glib-based library for talking to WWAN modems and devices
which speak the Mobile Interface Broadband Model (MBIM) protocol.

%package -n libmbim-glib4
Summary:        Mobile Interface Broadband Model (MBIM) protocol
License:        LGPL-2.1+
Group:          System/Libraries

%description -n libmbim-glib4
libmbim is a glib-based library for talking to WWAN modems and devices
which speak the Mobile Interface Broadband Model (MBIM) protocol.

%package devel
Summary:        Mobile Interface Broadband Model (MBIM) protocol - Development files
License:        LGPL-2.1+
Group:          Development/Languages/C and C++
Requires:       libmbim-glib4 = %{version}

%description devel
libmbim is a glib-based library for talking to WWAN modems and devices
which speak the Mobile Interface Broadband Model (MBIM) protocol.

%package -n mbimcli-bash-completion
Summary:        Bash completion for mbimcli
License:        GPL-2.0+ and LGPL-2.0+
Group:          Productivity/Networking/System
Supplements:    packageand(%{name}:bash-completion)
BuildRequires:  bash-completion
Requires:       bash-completion

%description -n mbimcli-bash-completion
This package contain de bash completion command for mbimcli tools.

%prep
%setup -q

%build
%configure \
    --with-udev \
    --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print

%post -n libmbim-glib4 -p /sbin/ldconfig

%postun -n libmbim-glib4 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING
%{_bindir}/mbim-network
%{_bindir}/mbimcli
%{_libexecdir}/mbim-proxy
%{_mandir}/man1/mbim-network.1%{?ext_man}
%{_mandir}/man1/mbimcli.1%{?ext_man}

%files -n libmbim-glib4
%defattr(-,root,root)
%{_libdir}/libmbim-glib.so.*

%files devel
%defattr(-,root,root)
%doc %{_datadir}/gtk-doc/html/libmbim-glib/
%{_includedir}/libmbim-glib/
%{_libdir}/libmbim-glib.so
%{_libdir}/pkgconfig/mbim-glib.pc

%files -n mbimcli-bash-completion
%defattr(-,root,root)
%{_datadir}/bash-completion/completions/mbimcli

%changelog
* Mon Jul 11 2016 bruno@ioda-net.ch
- Update to version 1.14.0:
  + New support for the 'QMI over MBIM' service, so that clients
    can use libqmi to build messages and libmbim to transport them.
  + The GUDev library, which we use to read the max message size
    from the USB descriptor, is now optional. When configuring, it
    will be used by default only if it's found. It can also be
    explicitly disabled using the new configure  switch
    '--without-udev' or explicitly enabled using '--with-udev'.
    If GUDev isn't used, libmbim-glib will rely on sysfs directly.
  + libmbim-glib updates: Added support for building messages of
    custom services.
  + mbim-network updates:
  - Added support for loading profiles from different paths using
    the new '--profile' option. This makes it possible to use
    mbim-network with multiple devices running in the same
    system.
  - Added support to allow specifying APN user (APN_USER),
    password (APN_PASS) and authentication type (APN_AUTH) in the
    profile.
  - Added support to allow using the mbim-proxy setup by
    configuring it in the profile file (PROXY=yes).
  + Several other minor improvements and fixes.
  + The following features which were backported to 1.12.x releases
    are also present in libmbim 1.14.0:
  - mbimcli updates:
    . Updated '--connect' arguments to allow specifying
    "key=value" pairs. The old legacy
    "[(APN),(PAP|CHAP|MSCHAPV2),(Username),(Password)]" format
    is kept as valid for backwards compatibility, although it
    should be assumed deprecated.
    . Longer timeouts for connect/register operations.
    . Report IP configuration when connected.
    . Allow specifying session ids.
  + libmbim-glib updates: Probing retry interval increased to 5s.
- Split out mbimcli-bash-completion package, requiring and
  supplementing bash-completion.
- Pass --with-udev to configure: new config parameter, but keeping
  the old behavior (it was non-optional before).
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Fri Mar 18 2016 zaitor@opensuse.org
- Update to version 1.12.4:
  + Updated '--connect' arguments to allow specifying "key=value"
    pairs. The old legacy "[(APN), (PAP|CHAP|MSCHAPV2), (Username),
    (Password)]" format is kept as valid for backwards
    compatibility, although it should be assumed deprecated.
  + mbimcli:
  - Longer timeouts for connect/register operations.
  - Report IP configuration when connected.
  - Allow specifying session ids.
  + libmbim-glib: probing retry interval increased to 5s.
  + Some other minor fixes.
* Sun Feb  1 2015 zaitor@opensuse.org
- Update to version 1.12.2:
  + Fix assertion triggered by a bug in the removal of unreleased
    transactions.
* Wed Jan 28 2015 dimstar@opensuse.org
- Update to version 1.12.0:
  + New `--enable-mbim-username' option during configure, which
    allows specifying which will be the user owning the
    /dev/cdc-wdm character devices of all MBIM modems (udev rules
    are installed to change file ownership). If this option is
    used, the mbim-proxy will only allow connections from processes
    running by the specified user or by the root user.
  + Function error messages can now be returned by the MbimDevice
    as responses to `Command', `Open' or `Close' messages. Users of
    the library should not assume the type of message returned to
    the previous actions.
  + The MbimProxy will monitor for 'NotOpened' errors, and when one
    detected it will directly close the internal MbimDevice. Any
    subsequent request sent by clients to that specific device will
    be aborted with a proxy-generated 'NotOpened' error. Clients
    will need to explicitly reopen the ports in that case.
  + The API now has a new mbim_message_response_get_result() method
    which allows getting a GError from a message which may be of a
    specific type (e.g. a `Command Done' message in response to a
    `Command' request) or instead the generic `Function Error'
    message type. Users of the library can use this new method to
    avoid assuming the type of message returned.
  + Other bugfixes and minor improvements:
  - Attach timeout and idle events to the thread-default context.
  - Fix bashisms in the mbim-network script.
- Drop libmbim-1.10.0-fix-bashisms.patch: fixed upstream.
* Thu Nov 27 2014 Led <ledest@gmail.com>
- Add libmbim-1.10.0-fix-bashisms.patch: fix bashisms in
  mbim-network script.
* Mon Oct 20 2014 dimstar@opensuse.org
- Update to version 1.10.0:
  + API break: Flag values in 'MbimRegistrationFlag' were updated
    to match the ones in the MBIM documentation.
  + Implemented a new 'mbim-proxy', which allows sharing a single
    MBIM control port among different processes. The usage of the
    proxy is optional, and can be requested by specifying the
    MBIM_DEVICE_OPEN_FLAGS_PROXY flag in the new
    mbim_device_open_full() method. The 'mbimcli' command line tool
    was also extended with a new '--device-open-proxy,-p' option,
    to allow requesting the use of the proxy process.
  + New 'removed' signal added to the MbimDevice, to notify when
    the underlying connection to the device is lost (e.g. lost
    connection to the mbim-proxy, or lost access to the MBIM
    control port).
  + Added support for registering and using custom services.
  + Added additional GMM cause codes to MbimNwError.
  + Transactions are now matched not only by ID but also by type.
  + Several other minor improvements and fixes.
- Changes from version 1.8.0:
  + Added support for additional MBIM messages:
  - MBIM_CID_MS_FIRMWARE_ID_GET
  - MBIM_CID_MS_HOST_SHUTDOWN_NOTIFY
  + Updated mbimcli with new commands:
  - --set-radio-state
  - --ms-query-firmware-id
  - --ms-notify-host-shutdown
  - --dss-connect
  - --dss-disconnect
  + Several enums and functions were renamed, and marked as
    deprecated. A small layer is given to provide backwards
    compatibility.
  + Several other minor improvements and fixes.
- Rename libmbim-glib0 subpackage to libmbim-glib4, following
  upstreams soname change.
* Sun Feb  2 2014 zaitor@opensuse.org
- Update to version 1.6.0:
  + Updated mbimcli with new commands:
  - -phonebook-query-configuration, --phonebook-read,
  - -phonebook-read-all, --phonebook-write, --phonebook-delete,
  - -phonebook-delete-all.
  + Added generation of man pages for mbimcli and mbim-network.
  + Several other minor improvements and fixes.
- Stop packaging Changelog in docs as it is empty.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update License fields:
  + Main package: GPL-2.0+ and LGPL-2.1+ (also for the src pkg).
  + Library and -devel subpackage: LGPL-2.1+.
  + The Small tools shipped in the main package (binary) are
    licensed GPL-2.0+.
* Wed Dec  4 2013 dimstar@opensuse.org
- Call ldconfig on post/postun of libmbim-glib0.
* Sun Dec  1 2013 dimstar@opensuse.org
- Initial package, version 1.4.0.
